@@ -29,7 +29,7 @@ static void geanypg_encrypt(encrypt_data * ed, gpgme_key_t * recp, int sign, int
     tempfile = tmpfile();
     if (!(tempfile))
     {
-        fprintf(stderr, "GeanyPG: %s: %s.\n", _("couldn't create tempfile"), strerror(errno));
+        g_warning("%s: %s.", _("couldn't create tempfile"), strerror(errno));
         return ;
     }
     gpgme_data_new_from_stream(&cipher, tempfile);
@@ -93,7 +93,7 @@ void geanypg_encrypt_cb(GtkMenuItem * menuitem, gpointer user_data)
             }
             if (*recp && !stop)
                 geanypg_encrypt(&ed, recp, sign, flags);
-            else if (!stop && dialogs_show_question(_("No recipients were selected,\nuse symetric cipher?")))
+            else if (!stop && dialogs_show_question(_("No recipients were selected,\nuse symmetric cipher?")))
                 geanypg_encrypt(&ed, NULL, sign, flags);
         }
         if (recp)
