@@ -21,7 +21,12 @@
  *       http://www.geany.org/manual/reference/howto.html
  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "PluginEntry.h"
+#include <errno.h>
 
 
 GeanyPlugin*           geany_plugin;
@@ -34,9 +39,9 @@ PLUGIN_SET_TRANSLATABLE_INFO(
     LOCALEDIR,
     GETTEXT_PACKAGE,
     _("XML PrettyPrinter"),
-    _("Formats an XML and makes it human-readable."),
+    _("Formats an XML and makes it human-readable. \nThis plugin currently"
+      "has no maintainer. Would you like to help by contributing to this plugin?"),
     PRETTY_PRINTER_VERSION, "Cédric Tabin - http://www.astorm.ch")
-PLUGIN_KEY_GROUP(prettyprinter, 1)
 
 /*========================================== DECLARATIONS ================================================================*/
 
@@ -49,8 +54,70 @@ static void config_closed(GtkWidget* configWidget, gint response, gpointer data)
 
 /*========================================== FUNCTIONS ===================================================================*/
 
+static gchar *
+get_config_file (void)
+{
+    gchar *dir;
+    gchar *fn;
+
+    dir = g_build_filename (geany_data->app->configdir, "plugins", "pretty-printer", NULL);
+    fn = g_build_filename (dir, "prefs.conf", NULL);
+
+    if (! g_file_test (fn, G_FILE_TEST_IS_DIR))
+    {
+        if (g_mkdir_with_parents (dir, 0755) != 0)
+        {
+            g_critical ("failed to create config dir '%s': %s", dir, g_strerror (errno));
+            g_free (dir);
+            g_free (fn);
+            return NULL;
+        }
+    }
+
+    g_free (dir);
+
+    if (! g_file_test (fn, G_FILE_TEST_EXISTS))
+    {
+        GError *error = NULL;
+        const gchar *def_config;
+
+        def_config = getDefaultPrefs(&error);
+        if (def_config == NULL)
+        {
+            g_critical ("failed to fetch default config data (%s)",
+                        error->message);
+            g_error_free (error);
+            g_free (fn);
+            return NULL;
+        }
+        if (!g_file_set_contents (fn, def_config, -1, &error))
+        {
+            g_critical ("failed to save default config to file '%s': %s",
+                        fn, error->message);
+            g_error_free (error);
+            g_free (fn);
+            return NULL;
+        }
+    }
+
+    return fn;
+}
+
 void plugin_init(GeanyData *data)
 {
+    gchar         *conf_file;
+    GError        *error = NULL;
+    GeanyKeyGroup *key_group;
+
+    /* load preferences */
+    conf_file = get_config_file ();
+    if (!prefsLoad (conf_file, &error))
+    {
+        g_critical ("failed to load preferences file '%s': %s", conf_file, error->message);
+        g_error_free (error);
+    }
+    g_free (conf_file);
+
     /* initializes the libxml2 */
     LIBXML_TEST_VERSION
 
@@ -62,7 +129,8 @@ void plugin_init(GeanyData *data)
     gtk_container_add(GTK_CONTAINER(geany->main_widgets->tools_menu), main_menu_item);
 
     /* init keybindings */
-    keybindings_set_item(plugin_key_group, 0, kb_run_xml_pretty_print,
+    key_group = plugin_set_key_group(geany_plugin, "prettyprinter", 1, NULL);
+    keybindings_set_item(key_group, 0, kb_run_xml_pretty_print,
                          0, 0, "run_pretty_printer_xml", _("Run the PrettyPrinter XML"),
                          main_menu_item);
 
@@ -92,7 +160,16 @@ void config_closed(GtkWidget* configWidget, gint response, gpointer gdata)
     if (response == GTK_RESPONSE_OK ||
         response == GTK_RESPONSE_APPLY)
     {
-        saveSettings();
+        gchar* conf_file;
+        GError* error = NULL;
+
+        conf_file = get_config_file ();
+        if (! prefsSave (conf_file, &error))
+        {
+            g_critical ("failed to save preferences to file '%s': %s", conf_file, error->message);
+            g_error_free (error);
+        }
+        g_free (conf_file);
     }
 }
 
@@ -107,13 +184,15 @@ void xml_format(GtkMenuItem* menuitem, gpointer gdata)
     GeanyDocument* doc = document_get_current();
     GeanyEditor* editor;
     ScintillaObject* sco;
-    int length;
-    char* buffer;
+    int input_length;
+    const gchar* input_buffer;
+    int output_length;
+    gchar* output_buffer;
     xmlDoc* parsedDocument;
     int result;
     int xOffset;
     GeanyFiletype* fileType;
-    
+
     g_return_if_fail(doc != NULL);
 
     editor = doc->editor;
@@ -122,17 +201,12 @@ void xml_format(GtkMenuItem* menuitem, gpointer gdata)
     /* default printing options */
     if (prettyPrintingOptions == NULL) { prettyPrintingOptions = createDefaultPrettyPrintingOptions(); }
 
-    /* prepare the buffer that will contain the text
-     * from the scintilla object */
-    length = sci_get_length(sco)+1;
-    buffer = (char*)malloc(length*sizeof(char));
-    if (buffer == NULL) { exit(-1); } /* malloc error */
-
     /* retrieves the text */
-    sci_get_text(sco, length, buffer);
+    input_length = sci_get_length(sco);
+    input_buffer = (gchar *) scintilla_send_message(sco, SCI_GETCHARACTERPOINTER, 0, 0);
 
     /* checks if the data is an XML format */
-    parsedDocument = xmlParseDoc((unsigned char*)buffer);
+    parsedDocument = xmlParseDoc((const unsigned char*)input_buffer);
 
     /* this is not a valid xml => exit with an error message */
     if(parsedDocument == NULL)
@@ -145,7 +219,7 @@ void xml_format(GtkMenuItem* menuitem, gpointer gdata)
     xmlFreeDoc(parsedDocument);
 
     /* process pretty-printing */
-    result = processXMLPrettyPrinting(&buffer, &length, prettyPrintingOptions);
+    result = processXMLPrettyPrinting(input_buffer, input_length, &output_buffer, &output_length, prettyPrintingOptions);
     if (result != PRETTY_PRINTING_SUCCESS)
     {
         dialogs_show_msgbox(GTK_MESSAGE_ERROR, _("Unable to process PrettyPrinting on the specified XML because some features are not supported.\n\nSee Help > Debug messages for more details..."));
@@ -153,7 +227,7 @@ void xml_format(GtkMenuItem* menuitem, gpointer gdata)
     }
 
     /* updates the document */
-    sci_set_text(sco, buffer);
+    sci_set_text(sco, output_buffer);
 
     /* set the line */
     xOffset = scintilla_send_message(sco, SCI_GETXOFFSET, 0, 0);
@@ -162,4 +236,6 @@ void xml_format(GtkMenuItem* menuitem, gpointer gdata)
     /* sets the type */
     fileType = filetypes_index(GEANY_FILETYPES_XML);
     document_set_filetype(doc, fileType);
+
+    g_free(output_buffer);
 }
