@@ -74,27 +74,35 @@ static GSList *get_file_list(const gchar *utf8_path, GSList *patterns,
 {
 	GSList *list = NULL;
 	GDir *dir;
+	const gchar *child_name;
+	GSList *child = NULL;
+	GSList *children = NULL;
 	gchar *locale_path = utils_get_locale_from_utf8(utf8_path);
-	gchar *real_path = tm_get_real_path(locale_path);
+	gchar *real_path = utils_get_real_path(locale_path);
 
 	dir = g_dir_open(locale_path, 0, NULL);
 	if (!dir || !real_path || g_hash_table_lookup(visited_paths, real_path))
 	{
 		g_free(locale_path);
 		g_free(real_path);
+		if (dir)
+			g_dir_close(dir);
 		return NULL;
 	}
 
 	g_hash_table_insert(visited_paths, real_path, GINT_TO_POINTER(1));
 
-	while (TRUE)
+	while ((child_name = g_dir_read_name(dir)))
+		children = g_slist_prepend(children, g_strdup(child_name));
+
+	g_dir_close(dir);
+
+	foreach_slist(child, children)
 	{
 		const gchar *locale_name;
 		gchar *locale_filename, *utf8_filename, *utf8_name;
 
-		locale_name = g_dir_read_name(dir);
-		if (!locale_name)
-			break;
+		locale_name = child->data;
 
 		utf8_name = utils_get_utf8_from_locale(locale_name);
 		locale_filename = g_build_filename(locale_path, locale_name, NULL);
@@ -123,7 +131,7 @@ static GSList *get_file_list(const gchar *utf8_path, GSList *patterns,
 		g_free(utf8_name);
 	}
 
-	g_dir_close(dir);
+	g_slist_free_full(children, g_free);
 	g_free(locale_path);
 
 	return list;
@@ -138,7 +146,7 @@ static gint prjorg_project_rescan_root(PrjOrgRoot *root)
 	GSList *ignored_file_list = NULL;
 	GHashTable *visited_paths;
 	GSList *lst;
-	GSList *elem;
+	GSList *elem = NULL;
 	gint filenum = 0;
 
 	source_files = g_ptr_array_new();
@@ -346,7 +354,7 @@ static void update_project(
 void prjorg_project_save(GKeyFile * key_file)
 {
 	GPtrArray *array;
-	GSList *elem, *lst;
+	GSList *elem = NULL, *lst;
 
 	if (!prj_org)
 		return;
@@ -404,8 +412,8 @@ static gint root_comparator(PrjOrgRoot *a, PrjOrgRoot *b)
 
 	a_locale_base_dir = utils_get_locale_from_utf8(a->base_dir);
 	b_locale_base_dir = utils_get_locale_from_utf8(b->base_dir);
-	a_realpath = tm_get_real_path(a_locale_base_dir);
-	b_realpath = tm_get_real_path(b_locale_base_dir);
+	a_realpath = utils_get_real_path(a_locale_base_dir);
+	b_realpath = utils_get_real_path(b_locale_base_dir);
 
 	res = g_strcmp0(a_realpath, b_realpath);
 
@@ -456,7 +464,7 @@ void prjorg_project_open(GKeyFile * key_file)
 {
 	gchar **source_patterns, **header_patterns, **ignored_dirs_patterns, **ignored_file_patterns, **external_dirs, **dir_ptr, *last_name;
 	gint generate_tag_prefs;
-	GSList *elem, *ext_list = NULL;
+	GSList *elem = NULL, *ext_list = NULL;
 	gchar *utf8_base_path;
 
 	if (prj_org != NULL)
@@ -555,13 +563,12 @@ void prjorg_project_read_properties_tab(void)
 }
 
 
-gint prjorg_project_add_properties_tab(GtkWidget *notebook)
+GtkWidget *prjorg_project_add_properties_tab(GtkWidget *notebook)
 {
 	GtkWidget *vbox, *hbox, *hbox1;
 	GtkWidget *table;
 	GtkWidget *label;
 	gchar *str;
-	gint page_index;
 
 	e = g_new0(PropertyDialogElements, 1);
 
@@ -645,10 +652,10 @@ gint prjorg_project_add_properties_tab(GtkWidget *notebook)
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 6);
 
-	page_index = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox, label);
 	gtk_widget_show_all(notebook);
 
-	return page_index;
+	return hbox;
 }
 
 
@@ -675,7 +682,7 @@ void prjorg_project_close(void)
 
 gboolean prjorg_project_is_in_project(const gchar *utf8_filename)
 {
-	GSList *elem;
+	GSList *elem = NULL;
 
 	if (!utf8_filename || !prj_org || !geany_data->app->project || !prj_org->roots)
 		return FALSE;
@@ -693,14 +700,14 @@ gboolean prjorg_project_is_in_project(const gchar *utf8_filename)
 
 static gboolean add_tm_idle(gpointer foo)
 {
-	GSList *elem2;
+	GSList *elem2 = NULL;
 
 	if (!prj_org || !s_idle_add_funcs)
 		return FALSE;
 
 	foreach_slist (elem2, s_idle_add_funcs)
 	{
-		GSList *elem;
+		GSList *elem = NULL;
 		gchar *utf8_fname = elem2->data;
 
 		foreach_slist (elem, prj_org->roots)
@@ -740,14 +747,14 @@ void prjorg_project_add_single_tm_file(gchar *utf8_filename)
 
 static gboolean remove_tm_idle(gpointer foo)
 {
-	GSList *elem2;
+	GSList *elem2 = NULL;
 
 	if (!prj_org || !s_idle_remove_funcs)
 		return FALSE;
 
 	foreach_slist (elem2, s_idle_remove_funcs)
 	{
-		GSList *elem;
+		GSList *elem = NULL;
 		gchar *utf8_fname = elem2->data;
 
 		foreach_slist (elem, prj_org->roots)
