@@ -205,10 +205,15 @@ gint sc_speller_process_line(GeanyDocument *doc, gint line_number)
 	gint suggestions_found = 0;
 	gint wordchars_len;
 	gchar *wordchars;
+	gchar *underscore_in_wordchars = NULL;
+	gboolean wordchars_modified = FALSE;
 
 	g_return_val_if_fail(sc_speller_dict != NULL, 0);
 	g_return_val_if_fail(doc != NULL, 0);
 
+	if (! DOC_VALID(doc))
+		return 0; /* current document has been closed */
+
 	/* add ' (single quote) temporarily to wordchars
 	 * to be able to check for "doesn't", "isn't" and similar */
 	wordchars_len = scintilla_send_message(doc->editor->sci, SCI_GETWORDCHARS, 0, 0);
@@ -218,9 +223,21 @@ gint sc_speller_process_line(GeanyDocument *doc, gint line_number)
 	{
 		/* temporarily add "'" to the wordchars */
 		wordchars[wordchars_len] = '\'';
+		wordchars_modified = TRUE;
+	}
+	underscore_in_wordchars = strchr(wordchars, '_');
+	if (underscore_in_wordchars != NULL)
+	{
+		/* Temporarily remove underscore from the wordchars to treat
+		 * it as a word seperator. Replace it by a "'" which we added already above. */
+		*underscore_in_wordchars = '\'';
+		wordchars_modified = TRUE;
+	}
+	if (wordchars_modified)
+	{
+		/* apply previously changed WORDCHARS setting */
 		scintilla_send_message(doc->editor->sci, SCI_SETWORDCHARS, 0, (sptr_t)wordchars);
 	}
-
 	pos_start = sci_get_position_from_line(doc->editor->sci, line_number);
 	pos_end = sci_get_position_from_line(doc->editor->sci, line_number + 1);
 
@@ -242,10 +259,15 @@ gint sc_speller_process_line(GeanyDocument *doc, gint line_number)
 		g_free(word);
 	}
 
-	/* reset wordchars for the current document */
-	wordchars[wordchars_len] = '\0';
-	scintilla_send_message(doc->editor->sci, SCI_SETWORDCHARS, 0, (sptr_t)wordchars);
-
+	if (wordchars_modified)
+	{
+		if (underscore_in_wordchars != NULL)
+			/* re-add underscore if we removed it above */
+			*underscore_in_wordchars = '_';
+		/* reset wordchars for the current document */
+		wordchars[wordchars_len] = '\0';
+		scintilla_send_message(doc->editor->sci, SCI_SETWORDCHARS, 0, (sptr_t)wordchars);
+	}
 	g_free(wordchars);
 	return suggestions_found;
 }
@@ -298,6 +320,11 @@ void sc_speller_check_document(GeanyDocument *doc)
 	{
 		for (i = first_line; i < last_line; i++)
 		{
+			if (! DOC_VALID(doc))
+			{	/* current document has been closed (might happen while checking large files) */
+				ui_progress_bar_stop();
+				return;
+			}
 			suggestions_found += sc_speller_process_line(doc, i);
 
 			/* process other GTK events to keep the GUI being responsive */
@@ -862,6 +889,7 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			break;
 		}
 		case SCLEX_HTML:
+		case SCLEX_PHPSCRIPT:
 		case SCLEX_XML:
 		{
 			switch (style)
@@ -1118,6 +1146,26 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_RUST:
+		{
+			switch (style)
+			{
+				case SCE_RUST_DEFAULT:
+				case SCE_RUST_COMMENTBLOCK:
+				case SCE_RUST_COMMENTBLOCKDOC:
+				case SCE_RUST_COMMENTLINE:
+				case SCE_RUST_COMMENTLINEDOC:
+				case SCE_RUST_STRING:
+				case SCE_RUST_STRINGR:
+				case SCE_RUST_BYTESTRING:
+				case SCE_RUST_BYTESTRINGR:
+				case SCE_RUST_LEXERROR:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_SQL:
 		{
 			switch (style)
